EXSWHTEC-251 - Implement Performance Tests for Stream APIs (#142)
Change-Id: I790d8cadb3a94a220a52c8bdc0a23b1a63931232
[ROCm/hip-tests commit: f05f97758e]
This commit is contained in:
committed by
Maneesh Gupta
parent
f1c9884299
commit
450d7159dd
@@ -0,0 +1,68 @@
|
||||
/*
|
||||
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
||||
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||
of this software and associated documentation files (the "Software"), to deal
|
||||
in the Software without restriction, including without limitation the rights
|
||||
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||
copies of the Software, and to permit persons to whom the Software is
|
||||
furnished to do so, subject to the following conditions:
|
||||
The above copyright notice and this permission notice shall be included in
|
||||
all copies or substantial portions of the Software.
|
||||
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include <hip_test_common.hh>
|
||||
#include <performance_common.hh>
|
||||
|
||||
/**
|
||||
* @addtogroup stream stream
|
||||
* @{
|
||||
* @ingroup PerformanceTest
|
||||
*/
|
||||
|
||||
class MallocAsyncBenchmark : public Benchmark<MallocAsyncBenchmark> {
|
||||
public:
|
||||
void operator()(const size_t array_size) {
|
||||
const StreamGuard stream_guard{Streams::created};
|
||||
const hipStream_t stream = stream_guard.stream();
|
||||
float* dev_ptr{nullptr};
|
||||
|
||||
TIMED_SECTION_STREAM(kTimerTypeEvent, stream) {
|
||||
HIP_CHECK(hipMallocAsync(reinterpret_cast<void**>(&dev_ptr), array_size * sizeof(float), stream));
|
||||
}
|
||||
HIP_CHECK(hipStreamSynchronize(stream));
|
||||
HIP_CHECK(hipFree(dev_ptr));
|
||||
}
|
||||
};
|
||||
|
||||
static void RunBenchmark(const size_t array_size) {
|
||||
MallocAsyncBenchmark benchmark;
|
||||
benchmark.AddSectionName(std::to_string(array_size));
|
||||
benchmark.Run(array_size);
|
||||
}
|
||||
|
||||
/**
|
||||
* Test Description
|
||||
* ------------------------
|
||||
* - Executes `hipMallocAsync` with created stream:
|
||||
* -# Allocation size:
|
||||
* - 4 KB
|
||||
* - 4 MB
|
||||
* - 16 MB
|
||||
* Test source
|
||||
* ------------------------
|
||||
* - performance/stream/hipMallocAsync.cc
|
||||
* Test requirements
|
||||
* ------------------------
|
||||
* - HIP_VERSION >= 5.2
|
||||
*/
|
||||
TEST_CASE("Performance_hipMallocAsync") {
|
||||
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
|
||||
RunBenchmark(array_size);
|
||||
}
|
||||
Reference in New Issue
Block a user